@@ -15,6 +15,7 @@ module DiasporaFederation
 
       # Fetches all metadata for the account and saves it via callback
       # @return [Person]
+      # @raise [DiscoveryError] if something with the discovery failed
       def fetch_and_save
         logger.info "Fetch data for #{diaspora_id}"
 
@@ -23,6 +24,10 @@ module DiasporaFederation
         DiasporaFederation.callbacks.trigger(:save_person_after_webfinger, person)
         logger.info "successfully webfingered #{diaspora_id}"
         person
+      rescue DiscoveryError
+        raise # simply re-raise DiscoveryError
+      rescue => e # rubocop:disable Style/RescueStandardError
+        raise DiscoveryError, "Failed discovery for #{diaspora_id}: #{e.class}: #{e.message}"
       end
 
       private
@@ -43,7 +48,7 @@ module DiasporaFederation
         response = HttpClient.get(url)
         raise "Failed to fetch #{url}: #{response.status}" unless response.success?
         response.body
-      rescue => e
+      rescue => e # rubocop:disable Style/RescueStandardError
         unless http_fallback && url.start_with?("https://")
           raise DiscoveryError, "Failed to fetch #{url} for #{diaspora_id}: #{e.class}: #{e.message}"
         end
@@ -53,23 +58,33 @@ module DiasporaFederation
         retry
       end
 
-      def host_meta_url
-        domain = diaspora_id.split("@")[1]
-        "https://#{domain}/.well-known/host-meta"
+      def domain
+        @domain ||= diaspora_id.split("@")[1]
+      end
+
+      def acct_parameter
+        "acct:#{diaspora_id}"
       end
 
       def legacy_webfinger_url_from_host_meta
         # This tries the xrd url with https first, then falls back to http.
-        host_meta = HostMeta.from_xml get(host_meta_url, true)
-        host_meta.webfinger_template_url.gsub("{uri}", "acct:#{diaspora_id}")
+        host_meta = HostMeta.from_xml(get("https://#{domain}/.well-known/host-meta", true))
+        host_meta.webfinger_template_url.gsub("{uri}", acct_parameter)
       end
 
       def webfinger
-        @webfinger ||= WebFinger.from_xml get(legacy_webfinger_url_from_host_meta)
+        return @webfinger if @webfinger
+        webfinger_url = "https://#{domain}/.well-known/webfinger?resource=#{acct_parameter}"
+
+        # This tries the WebFinger URL with https first, then falls back to http if webfinger_http_fallback is enabled.
+        @webfinger = WebFinger.from_json(get(webfinger_url, DiasporaFederation.webfinger_http_fallback))
+      rescue => e # rubocop:disable Style/RescueStandardError
+        logger.warn "WebFinger failed, retrying with legacy WebFinger for #{diaspora_id}: #{e.class}: #{e.message}"
+        @webfinger = WebFinger.from_xml(get(legacy_webfinger_url_from_host_meta))
       end
 
       def hcard
-        @hcard ||= HCard.from_html get(webfinger.hcard_url)
+        @hcard ||= HCard.from_html(get(webfinger.hcard_url))
       end
 
       def person
