@@ -13,6 +13,7 @@ require "diaspora_federation/entities/related_entity"
 # abstract types
 require "diaspora_federation/entities/post"
 require "diaspora_federation/entities/signable"
+require "diaspora_federation/entities/account_migration/signable"
 require "diaspora_federation/entities/relayable"
 
 # types
@@ -29,6 +30,7 @@ require "diaspora_federation/entities/poll_answer"
 require "diaspora_federation/entities/poll"
 require "diaspora_federation/entities/poll_participation"
 
+require "diaspora_federation/entities/embed"
 require "diaspora_federation/entities/location"
 
 require "diaspora_federation/entities/event"
