@@ -8,26 +8,26 @@ module DiasporaFederation
       #   The diaspora* ID of the person initiated the conversation
       #   @see Person#author
       #   @return [String] diaspora* ID
-      property :author, xml_name: :diaspora_handle
+      property :author, :string, xml_name: :diaspora_handle
 
       # @!attribute [r] guid
       #   A random string of at least 16 chars
       #   @see Validation::Rule::Guid
       #   @return [String] conversation guid
-      property :guid
+      property :guid, :string
 
       # @!attribute [r] subject
       #   @return [String] the conversation subject
-      property :subject
+      property :subject, :string
 
       # @!attribute [r] created_at
       #   @return [Time] Conversation creation time
-      property :created_at, default: -> { Time.now.utc }
+      property :created_at, :timestamp, default: -> { Time.now.utc }
 
       # @!attribute [r] participants
       #   The diaspora* IDs of the persons participating the conversation separated by ";"
       #   @return [String] participants diaspora* IDs
-      property :participants, xml_name: :participant_handles
+      property :participants, :string, xml_name: :participant_handles
 
       # @!attribute [r] messages
       #   @return [[Entities::Message]] Messages of this conversation
