@@ -17,7 +17,7 @@ module DiasporaFederation
         # Validates and receives the entity
         def receive
           validate_and_receive
-        rescue => e
+        rescue => e # rubocop:disable Style/RescueStandardError
           logger.error "failed to receive #{entity}"
           raise e
         end
@@ -28,6 +28,7 @@ module DiasporaFederation
 
         def validate_and_receive
           validate
+          fetch_linked_entities_from_text
           DiasporaFederation.callbacks.trigger(:receive_entity, entity, sender, recipient_id)
           logger.info "successfully received #{entity} from person #{sender}#{" for #{recipient_id}" if recipient_id}"
         end
@@ -43,6 +44,10 @@ module DiasporaFederation
             sender == entity.author
           end
         end
+
+        def fetch_linked_entities_from_text
+          DiasporaUrlParser.fetch_linked_entities(entity.text) if entity.respond_to?(:text) && entity.text
+        end
       end
     end
   end
