@@ -2,7 +2,7 @@ require "faraday"
 require "faraday_middleware/response/follow_redirects"
 
 module DiasporaFederation
-  # A wrapper for {https://github.com/lostisland/faraday Faraday}.
+  # A wrapper for {https://github.com/lostisland/faraday Faraday}
   #
   # @see Discovery::Discovery
   # @see Federation::Fetcher
@@ -15,7 +15,7 @@ module DiasporaFederation
       connection.get(uri)
     end
 
-    # gets the Faraday connection
+    # Gets the Faraday connection
     #
     # @return [Faraday::Connection] the response
     def self.connection
@@ -23,7 +23,7 @@ module DiasporaFederation
       @connection.dup
     end
 
-    def self.create_default_connection
+    private_class_method def self.create_default_connection
       options = {
         request: {timeout: DiasporaFederation.http_timeout},
         ssl:     {ca_file: DiasporaFederation.certificate_authorities}
@@ -36,6 +36,5 @@ module DiasporaFederation
 
       @connection.headers["User-Agent"] = DiasporaFederation.http_user_agent
     end
-    private_class_method :create_default_connection
   end
 end
