@@ -1,12 +1,12 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::EventParticipation}.
-    class EventParticipationValidator < Validation::Validator
+    class EventParticipationValidator < OptionalAwareValidator
       include Validation
 
       include RelayableValidator
 
-      rule :status, regular_expression: {regex: /\A(accepted|declined|tentative)\z/}
+      rule :status, [:not_empty, regular_expression: {regex: /\A(accepted|declined|tentative)\z/}]
     end
   end
 end
