@@ -1,18 +1,16 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Reshare}.
-    class ReshareValidator < Validation::Validator
+    class ReshareValidator < OptionalAwareValidator
       include Validation
 
-      rule :root_author, %i[not_empty diaspora_id]
+      rule :root_author, :diaspora_id
 
       rule :root_guid, :guid
 
-      rule :author, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
 
       rule :guid, :guid
-
-      rule :public, :boolean
     end
   end
 end
