@@ -1,10 +1,10 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Retraction}.
-    class RetractionValidator < Validation::Validator
+    class RetractionValidator < OptionalAwareValidator
       include Validation
 
-      rule :author, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
 
       rule :target_guid, :guid
       rule :target_type, :not_empty
